@@ -105,6 +105,22 @@ pub enum ErrorCode {
     #[fluvio(tag = 5001)]
     #[error("the managed connector was not found")]
     ManagedConnectorNotFound,
+
+    // Smart Module Errors
+    #[fluvio(tag = 6000)]
+    #[error("an error occurred while managing a smart module")]
+    SmartModuleError,
+    #[fluvio(tag = 6001)]
+    #[error("the smart module was not found")]
+    SmartModuleNotFound,
+
+    // Table Errors
+    #[fluvio(tag = 7000)]
+    #[error("a table error occurred")]
+    TableError,
+    #[fluvio(tag = 7001)]
+    #[error("the table was not found")]
+    TableNotFound,
 }
 
 impl Default for ErrorCode {
@@ -139,6 +155,8 @@ pub enum SmartStreamError {
     Runtime(#[from] SmartStreamRuntimeError),
     #[error("WASM Module error: {0}")]
     InvalidWasmModule(String),
+    #[error("WASM module is not a valid '{0}' SmartStream. Are you missing a #[smartstream({0})] attribute?")]
+    InvalidSmartStreamModule(String),
 }
 
 impl Default for SmartStreamError {
